@@ -1,4 +1,4 @@
-from .client import Client
+from .client import LanguageClient
 from .client import make_test_client
 from .plugin import fixture
 from .plugin import make_client_server
@@ -7,12 +7,12 @@ from .plugin import pytest_runtest_makereport
 from .plugin import ClientServer
 from .plugin import ClientServerConfig
 
-__version__ = "0.1.3"
+__version__ = "0.2.0"
 
 __all__ = [
-    "Client",
     "ClientServer",
     "ClientServerConfig",
+    "LanguageClient",
     "fixture",
     "make_client_server",
     "make_test_client",
